==> jc-1.4.0.tar.gz: soot/baf/BafBody.h <==
// public class soot.baf.BafBody

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 1719f85105e32350 soot_baf_BafBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_Body

#include "soot/Body.h"

#ifndef _JC_soot_baf_BafBody_H_
#define _JC_soot_baf_BafBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_baf_BafBody$sub_refs	_jc_soot_baf_BafBody$sub_refs;
typedef struct _jc_soot_baf_BafBody$sub_nonrefs	_jc_soot_baf_BafBody$sub_nonrefs;
typedef struct _jc_soot_baf_BafBody$refs	_jc_soot_baf_BafBody$refs;
typedef struct _jc_soot_baf_BafBody$nonrefs	_jc_soot_baf_BafBody$nonrefs;
typedef struct _jc_soot_baf_BafBody$object	_jc_soot_baf_BafBody$object;

typedef const struct _jc_soot_baf_BafBody$vmethods	_jc_soot_baf_BafBody$vmethods;
typedef const struct _jc_soot_baf_BafBody$vtable	_jc_soot_baf_BafBody$vtable;
typedef const struct _jc_soot_baf_BafBody$vtype	_jc_soot_baf_BafBody$vtype;

// Constructors
extern void _jc_soot_baf_BafBody$method$_init$82b8b4d7651faffa(_jc_env *, struct _jc_soot_baf_BafBody$object *, struct _jc_soot_Body$object *, struct _jc_object *);
extern void _jc_soot_baf_BafBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_baf_BafBody$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_baf_BafBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_BafBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_BafBody$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_baf_BafBody$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_BafBody$object *);
};

// Vtable
struct _jc_soot_baf_BafBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_baf_BafBody$vmethods	soot_baf_BafBody;
};

// Vtype
struct _jc_soot_baf_BafBody$vtype {
	_jc_type			type;
	_jc_soot_baf_BafBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_BafBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_BafBody$refs {
    _jc_soot_baf_BafBody$sub_refs	soot_baf_BafBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_BafBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_BafBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_baf_BafBody$sub_nonrefs	soot_baf_BafBody;
};

// Object instance structure
struct _jc_soot_baf_BafBody$object {
	_jc_soot_baf_BafBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_BafBody$vtype	*vtype;
	_jc_soot_baf_BafBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_BafBody$vtype _jc_soot_baf_BafBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_BafBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_BafBody$class_object;

#endif	/* _JC_soot_baf_BafBody_H_ */

==> jc-1.4.6.tar.gz: soot/baf/BafBody.h <==
// public class soot.baf.BafBody

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 1719f85105e32350 soot_baf_BafBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_Body

#include "soot/Body.h"

#ifndef _JC_soot_baf_BafBody_H_
#define _JC_soot_baf_BafBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_baf_BafBody$sub_refs	_jc_soot_baf_BafBody$sub_refs;
typedef struct _jc_soot_baf_BafBody$sub_nonrefs	_jc_soot_baf_BafBody$sub_nonrefs;
typedef struct _jc_soot_baf_BafBody$refs	_jc_soot_baf_BafBody$refs;
typedef struct _jc_soot_baf_BafBody$nonrefs	_jc_soot_baf_BafBody$nonrefs;
typedef struct _jc_soot_baf_BafBody$object	_jc_soot_baf_BafBody$object;

typedef const struct _jc_soot_baf_BafBody$vmethods	_jc_soot_baf_BafBody$vmethods;
typedef const struct _jc_soot_baf_BafBody$vtable	_jc_soot_baf_BafBody$vtable;
typedef const struct _jc_soot_baf_BafBody$vtype	_jc_soot_baf_BafBody$vtype;

// Constructors
extern void _jc_soot_baf_BafBody$method$_init$82b8b4d7651faffa(_jc_env *, struct _jc_soot_baf_BafBody$object *, struct _jc_soot_Body$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_BafBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_baf_BafBody$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_baf_BafBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_BafBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_BafBody$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_baf_BafBody$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_BafBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_BafBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_baf_BafBody$vmethods	soot_baf_BafBody;
};

// Vtype
struct _jc_soot_baf_BafBody$vtype {
	_jc_type			type;
	_jc_soot_baf_BafBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_BafBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_BafBody$refs {
    _jc_soot_baf_BafBody$sub_refs	soot_baf_BafBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_BafBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_BafBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_baf_BafBody$sub_nonrefs	soot_baf_BafBody;
};

// Object instance structure
struct _jc_soot_baf_BafBody$object {
	_jc_soot_baf_BafBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_BafBody$vtype	*vtype;
	_jc_soot_baf_BafBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_BafBody$vtype _jc_soot_baf_BafBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_BafBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_BafBody$class_object;

#endif	/* _JC_soot_baf_BafBody_H_ */
